use serde::{Deserialize, Serialize};
use time::OffsetDateTime;

#[derive(Clone, Debug, Deserialize)]
pub struct Ref {
    pub r#ref: String,
}

#[derive(Clone, Debug, Deserialize)]
pub struct User {
    pub login: String,
}

#[derive(Clone, Debug, Deserialize)]
pub struct PullRequest {
    pub number: u64,
    pub title: String,
    pub user: User,
    pub base: Ref,
    pub head: Ref,
}

#[derive(Copy, Clone, Deserialize, Serialize, Debug)]
#[serde(rename_all = "snake_case")]
pub enum PackageType {
    Generic,
}

impl std::fmt::Display for PackageType {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            PackageType::Generic => write!(f, "generic"),
        }
    }
}

#[derive(Clone, Debug, Deserialize)]
pub struct Package {
    #[serde(with = "time::serde::iso8601")]
    pub created_at: OffsetDateTime,
    pub id: u64,
    pub name: String,
    pub owner: User,
    pub r#type: PackageType,
    pub version: String,
}
